-----------------------------------------------------------------------------------------------
-- Client Lua Script for Walatiki Timer
-- Copyright (c) Shikaga. All rights reserved
-----------------------------------------------------------------------------------------------
 
require "Window"
 
-----------------------------------------------------------------------------------------------
-- Walatiki Timer Module Definition
-----------------------------------------------------------------------------------------------
local WalatikiTimer = {}
 
-----------------------------------------------------------------------------------------------
-- Initialization
-----------------------------------------------------------------------------------------------
function WalatikiTimer:new(o)
    o = o or {}
    setmetatable(o, self)
    self.__index = self 

    self.startTime = nil
    self.unearthedDropppedTime = nil

    return o
end

function WalatikiTimer:Init()
	self.xmlDoc = XmlDoc.CreateFromFile("WalatikiTimer.xml")
	self.timers = {}

	Apollo.RegisterSlashCommand("wt", "OnSlashCommand", self) 

	local bHasConfigureFunction = false
	local strConfigureButtonText = "WalatikiTimer"
	local tDependencies = {} 
	Apollo.RegisterTimerHandler("OneSecTimer", "OnTimer", self)
    Apollo.RegisterAddon(self, bHasConfigureFunction, strConfigureButtonText, tDependencies)

    Apollo.RegisterEventHandler("ChatMessage","OnChatMessage", self)
end


function WalatikiTimer:OnSlashCommand()
	self:LoadWindow()
end

function WalatikiTimer:OnLoad()
end

function round(num, idp)
  local mult = 10^(idp or 0)
  return math.floor(num * mult + 0.5) / mult
end

function WalatikiTimer:LoadWindow( ... )
	if not self.wndMain then
		self.xmlDoc = XmlDoc.CreateFromFile("WalatikiTimer.xml")
		self.wndMain = Apollo.LoadForm(self.xmlDoc, "Timer", nil, self)
		self.wndMain:Invoke()
	end
end

function WalatikiTimer:OnTimer()
	self:CheckUnearthedDespawns()
	if self.wndMain then
		self.wndMain:DestroyChildren()
		local timerRow = Apollo.LoadForm(self.xmlDoc, "TimerRow", self.wndMain, self)
		timerRow:FindChild("Time"):SetText("WalatikiTimer")
		for _,time in pairs(self.timers) do
			local dTime = round(60 - (GameLib.GetGameTime() - time))
			if dTime > 0 then
				local timerRow = Apollo.LoadForm(self.xmlDoc, "TimerRow", self.wndMain, self)
				timerRow:FindChild("Time"):SetText(dTime)
			else
			end
		end
		self.wndMain:ArrangeChildrenVert(0)
	else
	end
end

function WalatikiTimer:CheckUnearthedDespawns()
	if self.unearthedDropppedTime then
		if (GameLib.GetGameTime() - self.unearthedDropppedTime) > 30 then
			table.insert(self.timers, GameLib.GetGameTime())
			self.unearthedDropppedTime = nil
		end
	end
end

function WalatikiTimer:UnearthedDropped()
	self.unearthedDropppedTime = GameLib.GetGameTime()
end

function WalatikiTimer:UnearthedPickedUp()
	self.unearthedDropppedTime = nil
end
 
function WalatikiTimer:OnChatMessage(channelCurrent, tMessage)
	if channelCurrent:GetName() == "Datachron" then
		local message = tMessage.arMessageSegments[1].strText
		if message == "The Dominion captured a Moodie Mask!" or message == "The Exiles captured a Moodie Mask!" then
			table.insert(self.timers, GameLib.GetGameTime())
		elseif message == "A Moodie Mask has been unearthed!"  then
			self:LoadWindow()
		elseif message == "The Dominion gathered a Moodie Mask!" or message == "The Exiles gathered a Moodie Mask!" then
			self:UnearthedPickedUp()
		elseif message == "The Dominion dropped a Moodie Mask!" or message == "The Exiles dropped a Moodie Mask!" then
			self:UnearthedDropped()
		else
			Print(message)
		end
	end
end

local WalatikiTimerInst = WalatikiTimer:new()
WalatikiTimerInst:Init()
